@@ -437,10 +437,13 @@ char *ExecutiveFindBestNameMatch(PyMOLGlobals * G, char *name);
 int ExecutiveSetVisFromPyDict(PyMOLGlobals * G, PyObject * dict);
 PyObject *ExecutiveGetVisAsPyDict(PyMOLGlobals * G);
 PyObject *ExecutiveGetVolumeField(PyMOLGlobals * G, char * objName);
-PyObject *ExecutiveGetVolumeHistogram(PyMOLGlobals * G, char * objName);
-PyObject *ExecutiveSetVolumeRamp(PyMOLGlobals * G, char * objName, float *ramp_list, int list_size);
+int       ExecutiveSetVolumeRamp(PyMOLGlobals * G, char * objName, float *ramp_list, int list_size);
 PyObject *ExecutiveGetVolumeRamp(PyMOLGlobals * G, char * objName);
-PyObject* ExecutiveGetVolumeIsUpdated(PyMOLGlobals * G, char* objName);
+int       ExecutiveGetVolumeIsUpdated(PyMOLGlobals * G, char* objName);
+
+float * ExecutiveGetHistogram(PyMOLGlobals * G, char* objName, int n_points,
+        float min_val, float max_val);
+
 int ExecutiveIterateObjectMolecule(PyMOLGlobals * G, ObjectMolecule ** obj,
                                    void **hidden);
 int ExecutiveSetObjectColor(PyMOLGlobals * G, char *name, char *color, int quiet);
@@ -525,7 +528,7 @@ int ExecutiveIsomeshEtc(PyMOLGlobals * G,
                         char *sele, float fbuf, int state,
                         float carve, int map_state, int quiet,
                         int mesh_mode, int box_mode, float alt_lvl);
-PyObject *ExecutiveAssignAtomTypes(PyMOLGlobals * G, char *s1, int format, int state, int quiet);
+int ExecutiveAssignAtomTypes(PyMOLGlobals * G, char *s1, int format, int state, int quiet);
 
 PyObject * ExecutiveCEAlign(PyMOLGlobals * G, PyObject * listA, PyObject * listB, int lenA, int lenB,
 			    float d0, float d1, int windowSize, int gapMax);
