@@ -72,6 +72,7 @@ if __name__=='pymol.invocation':
     options.no_quit = 0
     options.plugins = 2
     options.exit_on_error = 0
+    options.pymolrc = None
 
     options.win_py = { 'irix':240,
                        'darwin': 214, # hmm...need to set to 192 for Leopard?...
@@ -91,7 +92,7 @@ if __name__=='pymol.invocation':
     py_re = re.compile(r"\.py$|\.pym$|\.PY$|\.PYM$")
 
     def get_user_config():
-        for d in [os.getcwd(), '$HOME', '$HOMEPATH$HOMEDRIVE', '$PYMOL_PATH']:
+        for d in [os.getcwd(), '$HOME', '$HOMEDRIVE$HOMEPATH', '$PYMOL_PATH']:
             d = os.path.expandvars(d)
             for pat in [pymolrc_pat1, pymolrc_pat2]:
                 lst = glob.glob(d + os.sep + pat)
@@ -107,9 +108,9 @@ if __name__=='pymol.invocation':
         second = []
         for a in lst:
             if py_re.search(a):
-                first.append("_do__ run "+a) # preceeding "_ " cloaks
+                first.append(a) # preceeding "_ " cloaks
             elif script_re.search(a):
-                second.append("_do__ @"+a) # preceeding "_ " cloaks 
+                second.append(a) # preceeding "_ " cloaks 
 
         first.sort()
         second.sort()
@@ -381,7 +382,9 @@ if __name__=='pymol.invocation':
                 options.deferred.append(a)
                 loaded_something = 1
         if pymolrc != None:
-            options.deferred = pymolrc + options.deferred
+            options.deferred = [('_do__ @' + a) if script_re.search(a) else a
+                    for a in pymolrc] + options.deferred
+            options.pymolrc = pymolrc
         if options.plugins == 1:
             # Load plugins independent of PMGApp (will not add menu items)
             options.deferred.append('_do__ /import pymol.plugins;pymol.plugins.initialize(-1)')
