@@ -198,6 +198,7 @@ def get_command_keywords(self_cmd=cmd):
         'recolor'       : [ self_cmd.recolor           , 0 , 0 , ''  , parsing.STRICT ],   
         'redo'          : [ self_cmd.redo              , 0 , 0 , ''  , parsing.STRICT ],
         'reference'     : [ self_cmd.reference         , 0 , 0 , ''  , parsing.STRICT ],
+        'volume_ramp_new': [ self_cmd.volume_ramp_new, 0 , 0 , ''  , parsing.STRICT ],
         'reinitialize'  : [ self_cmd.reinitialize      , 0 , 0 , ''  , parsing.STRICT ],      
         'refresh'       : [ self_cmd.refresh           , 0 , 0 , ''  , parsing.STRICT ],
         'refresh_wizard': [ self_cmd.refresh_wizard    , 0 , 0 , ''  , parsing.STRICT ],
@@ -275,6 +276,7 @@ def get_command_keywords(self_cmd=cmd):
         'viewport'      : [ self_cmd.viewport          , 0 , 0 , ''  , parsing.STRICT ],
         'volume'        : [ self_cmd.volume            , 0 , 0 , ''  , parsing.STRICT ],
         'volume_color'  : [ self_cmd.volume_color      , 0 , 0 , ''  , parsing.STRICT ],
+        'volume_panel'  : [ self_cmd.volume_panel      , 0 , 0 , ''  , parsing.STRICT ],
         'window'        : [ self_cmd.window            , 0 , 0 , ''  , parsing.STRICT ],         
         'while'         : [ self_cmd.python_help       , 0 , 0 , ''  , parsing.PYTHON ],   
         'wizard'        : [ self_cmd.wizard            , 0 , 0 , ''  , parsing.STRICT ],
